obelisk.strategies.retry.ExponentialBackoffStrategy
===================================================

.. currentmodule:: obelisk.strategies.retry

.. autoclass:: ExponentialBackoffStrategy
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ExponentialBackoffStrategy.__init__
      ~ExponentialBackoffStrategy.make
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ExponentialBackoffStrategy.max_retries
      ~ExponentialBackoffStrategy.backoff
      ~ExponentialBackoffStrategy.max_backoff
   
   